Package 'fastpolicytree'
| Title: |
Constructs Policy Trees from Covariate and Reward Data |
| Description: |
Constructs optimal policy trees which provide a rule-based
treatment prescription policy. Input is covariate and reward
data, where, typically, the rewards will be doubly robust
reward estimates. This package aims to construct optimal policy
trees more quickly than the existing 'policytree' package and
is intended to be used alongside that package. For more details
see Cussens, Hatamyar, Shah and Kreif (2025)
<doi:10.48550/arXiv.2506.15435>. |
| Authors: |
James Cussens [aut, cre] (ORCID:
<https://orcid.org/0000-0002-1363-2336>),
Julia Hatamyar [ctb],
Vishalie Shah [ctb],
University of Bristol [cph],
MRC [fnd] |
| Maintainer: |
James Cussens <[email protected]> |
| License: |
GPL (>= 3) |
| Version: |
1.0 |
| Built: |
2026-06-02 09:31:41 UTC |
| Source: |
https://github.com/jcussens/tailoring |
Help Index